pub struct JsPenalty {
pub kanji_penalty_length_threshold: u32,
pub kanji_penalty_length_penalty: i32,
pub other_penalty_length_threshold: u32,
pub other_penalty_length_penalty: i32,
}Expand description
Penalty configuration for decompose mode.
Controls how aggressively compound words are decomposed based on character type and length thresholds.
Fields
kanji_penalty_length_threshold: u32Length threshold for kanji sequences before applying penalty (default: 2).
kanji_penalty_length_penalty: i32Penalty value for long kanji sequences (default: 3000).
other_penalty_length_threshold: u32Length threshold for other character sequences before applying penalty (default: 7).
other_penalty_length_penalty: i32Penalty value for long other-character sequences (default: 1700).