Training functionality for custom morphological models.
This module provides functions for training custom morphological analysis models
from annotated corpora. Requires the train feature.
Structs
- Export
Options - Options for exporting a trained model.
- Train
Options - Options for training a CRF model.
Functions
- export_
model - Exports dictionary files from a trained model.
- train
- Trains a morphological analysis model from an annotated corpus.