pub struct JsUserDictionary { /* private fields */ }Expand description
A user-defined dictionary for custom words.
User dictionaries allow you to add custom words and their morphological features that are not present in the main dictionary.