pub struct JsTokenizerBuilder { /* private fields */ }Expand description
Builder for creating a Tokenizer with custom configuration.
The builder pattern allows for fluent configuration of tokenizer parameters including dictionaries, modes, and filter pipelines.
Implementations
Sourceimpl JsTokenizerBuilder
impl JsTokenizerBuilder
Sourcepub fn from_file(&self, file_path: String) -> Result<JsTokenizerBuilder>
pub fn from_file(&self, file_path: String) -> Result<JsTokenizerBuilder>
Sourcepub fn set_dictionary(&mut self, path: String)
pub fn set_dictionary(&mut self, path: String)
Sets the dictionary path or URI.
Arguments
path- Path to the dictionary directory or embedded URI (e.g. “embedded://ipadic”).
Sourcepub fn set_user_dictionary(&mut self, uri: String)
pub fn set_user_dictionary(&mut self, uri: String)
Sourcepub fn set_keep_whitespace(&mut self, keep_whitespace: bool)
pub fn set_keep_whitespace(&mut self, keep_whitespace: bool)
Sets whether to keep whitespace in tokenization results.
Arguments
keep_whitespace- If true, whitespace tokens will be included in results.
Sourcepub fn append_character_filter(
&mut self,
kind: String,
args: Option<Value>,
) -> Result<()>
pub fn append_character_filter( &mut self, kind: String, args: Option<Value>, ) -> Result<()>
Appends a character filter to the preprocessing pipeline.
Arguments
kind- Type of character filter to add (e.g. “unicode_normalize”, “mapping”).args- Optional filter arguments as a JSON-compatible object.
Sourcepub fn append_token_filter(
&mut self,
kind: String,
args: Option<Value>,
) -> Result<()>
pub fn append_token_filter( &mut self, kind: String, args: Option<Value>, ) -> Result<()>
Appends a token filter to the postprocessing pipeline.
Arguments
kind- Type of token filter to add (e.g. “lowercase”, “japanese_stop_tags”).args- Optional filter arguments as a JSON-compatible object.
Sourcepub fn build(&self) -> Result<JsTokenizer>
pub fn build(&self) -> Result<JsTokenizer>
Builds the tokenizer with the configured settings.
Returns
A configured Tokenizer instance ready for use.